use axum::Router;
use axum::routing::get;
use crate::base::controller::BaseController;

use super::model::User;
use super::service::UserService;

pub struct UserController {
    base_controller: BaseController<User, UserService>,
}

impl UserController {
    pub fn new(service: UserService) -> Self {
        Self {
            base_controller: BaseController::new(service),
        }
    }

    pub fn routes() -> Router {
        Router::new()
            .route("/users", get(Self::get_users))
    }

    async fn get_users(
        State(controller): State<Arc<UserController>>,
    ) -> impl IntoResponse {
        controller.base_controller.get_all().await
    }
}
